@@ -6,7 +6,7 @@ our $AUTHORITY = 'cpan:GENE';
 use strict;
 use warnings;
 
-our $VERSION = '0.0803';
+our $VERSION = '0.0804';
 
 use Bit::Vector;
 use DBI;
@@ -417,55 +417,51 @@ Lingua::Word::Parser - Parse a word into scored known and unknown parts
 
 =head1 VERSION
 
-version 0.0803
+version 0.0804
 
 =head1 SYNOPSIS
 
  use Lingua::Word::Parser;
- my $p = Lingua::Word::Parser->new(
-    word => 'abioticaly',
-    file => 'eg/lexicon.dat',
- );
 
- # Or with a database source:
- $p = Lingua::Word::Parser->new(
+ # With a database source:
+ my $p = Lingua::Word::Parser->new(
     word   => 'abioticaly',
     dbname => 'fragments',
     dbuser => 'akbar',
     dbpass => 's3kr1+',
  );
 
+ # With a file source:
+ $p = Lingua::Word::Parser->new(
+    word => 'abioticaly',
+    file => 'eg/lexicon.dat',
+ );
+
  my $known  = $p->knowns;
  my $combos = $p->power;
- my $parts  = $p->score_parts;
+ my $score  = $p->score;    # Stringified output
+ #my $score  = $p->score_parts; # "Raw" output
 
  # The best guess is the last sorted scored set:
- print Dumper $scored->{ [ sort keys %$scored ]->[-1] };
+ print Dumper $score->{ [ sort keys %$score ]->[-1] };
 
 =head1 DESCRIPTION
 
 A C<Lingua::Word::Parser> breaks a word into known affixes.
 
-A (word-part => regular-expression) lexicon file must have lines of
-the form:
+A word-part lexicon file must have "regular-expression definition"
+lines of the form:
 
  a(?=\w)        opposite
  ab(?=\w)       away
  (?<=\w)o(?=\w) combining
  (?<=\w)tic     possessing
 
-Please see the included F<eg/lexicon.dat> file.
+Please see the included F<eg/lexicon.dat> example file.
 
-A database lexicon must have records of the form:
-
-         affix     definition
-  -----------------------------
-         a(?=\w)   opposite
-         ab(?=\w)  away
-  (?<=\w)o(?=\w)   combining
-  (?<=\w)tic       possessing
-
-Please see the included F<eg/word_part.sql> file.
+A database lexicon must have records as above, but with the column
+names, B<affix> and B<definition>.  Please see the included
+F<eg/word_part.sql> example file.
 
 =head1 METHODS
 
@@ -503,7 +499,7 @@ all masks.
   $score = $p->score( $open_separator, $close_separator);
 
 Score the known vs unknown word part combinations into ratios of characters and
-chunks or parts or "spans of adjacent characters" B<as a collection of strings>.
+chunks, word familiarity, partitions and definitions.
 
 This method sets the B<score> member to a list of hashrefs with keys:
 
@@ -522,7 +518,7 @@ default.
   $score_parts = $p->score_parts( $open_separator, $close_separator, $line_terminator );
 
 Score the known vs unknown word part combinations into ratios of characters and
-chunks (spans of adjacent characters).
+chunks, word familiarity, partitions and definitions.
 
 If not given, the B<$open_separator> and B<$close_separator> are '<' and '>' by
 default.
